PaymentModel class

Constructors

PaymentModel({required String transactionId, String status = '', int amount = 0, int fee = 0, String currency = '', int refunded = 0, String refundedAt = '', int captured = 0, String capturedAt = '', String voidedAt = '', String description = '', String amountFormat = '', String feeFormat = '', String refundedFormat = '', String capturedFormat = '', String invoiceId = '', String ip = '', String callbackUrl = '', String createdAt = '', String updatedAt = ''})
PaymentModel is the constructor of the class of the payment transaction.
PaymentModel.fromJson(Map<String, dynamic> json)
PaymentModel.fromJson is a method that converts a JSON object into a PaymentModel object.

Properties

amount int
amount is the amount of the payment transaction.
getter/setter pair
amountFormat String
amountFormat is the formatted amount of the payment transaction.
getter/setter pair
callbackUrl String
callbackUrl is the URL to which the payment transaction callback should be sent.
getter/setter pair
captured int
captured is the amount captured for the payment transaction.
getter/setter pair
capturedAt String
capturedAt is the date and time when the payment transaction was captured.
getter/setter pair
capturedFormat String
capturedFormat is the formatted amount captured for the payment transaction.
getter/setter pair
createdAt String
createdAt is the date and time when the payment transaction was created.
getter/setter pair
currency String
currency is the currency used for the payment transaction.
getter/setter pair
description String
description is the description of the payment transaction.
getter/setter pair
fee int
fee is the fee associated with the payment transaction.
getter/setter pair
feeFormat String
feeFormat is the formatted fee associated with the payment transaction.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
invoiceId String
invoiceId is the unique identifier of the invoice associated with the payment transaction.
getter/setter pair
ip String
ip is the IP address of the device used for the payment transaction.
getter/setter pair
refunded int
refunded is the amount refunded for the payment transaction.
getter/setter pair
refundedAt String
refundedAt is the date and time when the payment transaction was refunded.
getter/setter pair
refundedFormat String
refundedFormat is the formatted amount refunded for the payment transaction.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
status is the status of the payment transaction.
getter/setter pair
transactionId String
transactionId is the unique identifier of the payment transaction.
getter/setter pair
updatedAt String
updatedAt is the date and time when the payment transaction was last updated.
getter/setter pair
voidedAt String
voidedAt is the date and time when the payment transaction was voided.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited