capturedFormat property
capturedFormat is the formatted amount captured for the payment transaction.
Implementation
late String capturedFormat;
capturedFormat is the formatted amount captured for the payment transaction.
late String capturedFormat;