refundedFormat property
refundedFormat is the formatted amount refunded for the payment transaction.
Implementation
late String refundedFormat;
refundedFormat is the formatted amount refunded for the payment transaction.
late String refundedFormat;