UniInvoiceDTO class

Constructors

UniInvoiceDTO({required String amount, UniPayCurrency currency = UniPayCurrency.sar, required String description, String? expiredAt, String? successUrl, String? backUrl, String? callBackUrl, Map<String, dynamic>? metadata})

Properties

amount String
The amount should be in the smallest currency unit. Means, ( 100 Halals to charges 1 Riyal )
getter/setter pair
backUrl String?
An endpoint on your site, that we will redirect to after the user clicks on the back button.
getter/setter pair
callBackUrl String?
An endpoint on your server, for receiving notifications about paid invoices..
getter/setter pair
currency ↔ UniPayCurrency
3-letter ISO code for currency. (default: SAR)
getter/setter pair
description String
An arbitrary string that you can attach to an invoice object. This may include a description of the merchandise or the service that your customer is billed for. The invoice description is displayed on the invoice alongside the amount when the invoice is presented to the user.
getter/setter pair
expiredAt String?
Specifies when the invoice will get expired. An expired invoice cannot have payment attempts as its status will be expired.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successUrl String?
An endpoint on your site, that we will redirect to after the customer pays successfully.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited