backUrl property
An endpoint on your site, that we will redirect to after the user clicks on the back button.
Implementation
String? backUrl;
An endpoint on your site, that we will redirect to after the user clicks on the back button.
String? backUrl;