expiredAt property
Specifies when the invoice will get expired. An expired invoice cannot have payment attempts as its status will be expired.
Implementation
String? expiredAt;
Specifies when the invoice will get expired. An expired invoice cannot have payment attempts as its status will be expired.
String? expiredAt;