successUrl property
An endpoint on your site, that we will redirect to after the customer pays successfully.
Implementation
String? successUrl;
An endpoint on your site, that we will redirect to after the customer pays successfully.
String? successUrl;