UniInvoiceModel class

Constructors

UniInvoiceModel({required String id, String status = '', int amount = 0, String currency = '', String description = '', String logoUrl = '', String amountFormat = '', String url = '', String callbackUrl = '', String expiredAt = '', String createdAt = '', String updatedAt = '', String backUrl = '', String successUrl = '', Map<String, dynamic> metadata = const {}})
UniInvoiceModel.fromJson(Map<String, dynamic> json)

Properties

amount int
getter/setter pair
amountFormat String
getter/setter pair
backUrl String
getter/setter pair
callbackUrl String
getter/setter pair
createdAt String
getter/setter pair
currency String
getter/setter pair
description String
getter/setter pair
expiredAt String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
logoUrl String
getter/setter pair
metadata Map<String, dynamic>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
successUrl String
getter/setter pair
updatedAt String
getter/setter pair
url String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited