PaymentsRes class
Constructors
-
PaymentsRes({required List<
PaymentModel> payments}) - PaymentsRes is hold the list of payment transactions.
-
PaymentsRes.fromJson(Map<
String, dynamic> json) -
fromJson is a factory method that creates a new instance of the PaymentsRes class from a map of dynamic objects.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
payments
↔ List<
PaymentModel> -
payments is the list of payment transactions.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited